from pydantic import BaseModel, Field
from typing import Optional
from datetime import datetime
from uuid import UUID

class CarBase(BaseModel):
    brand: str = Field(..., description="Car brand")
    model: str = Field(..., description="Car model")
    year: int = Field(..., description="Manufacturing year")
    color: Optional[str] = Field(None, description="Car color")
    vin: str = Field(..., description="Vehicle Identification Number")
    price: int = Field(..., description="Car price")
    is_available: bool = Field(True, description="Availability status")
    mileage: int = Field(0, description="Current mileage")

class CarCreate(CarBase):
    pass

class CarUpdate(BaseModel):
    brand: Optional[str] = Field(None, description="Car brand")
    model: Optional[str] = Field(None, description="Car model") 
    year: Optional[int] = Field(None, description="Manufacturing year")
    color: Optional[str] = Field(None, description="Car color")
    vin: Optional[str] = Field(None, description="Vehicle Identification Number")
    price: Optional[int] = Field(None, description="Car price")
    is_available: Optional[bool] = Field(None, description="Availability status")
    mileage: Optional[int] = Field(None, description="Current mileage")

class CarSchema(CarBase):
    id: UUID
    created_at: datetime
    updated_at: datetime

    class Config:
        orm_mode = True
        schema_extra = {
            "example": {
                "id": "f47ac10b-58cc-4372-a567-0e02b2c3d479",
                "brand": "BMW",
                "model": "M3",
                "year": 2023,
                "color": "Black",
                "vin": "1HGCM82633A123456",
                "price": 85000,
                "is_available": True,
                "mileage": 0,
                "created_at": "2023-01-01T12:00:00",
                "updated_at": "2023-01-01T12:00:00"
            }
        }